@@ -5,13 +5,13 @@ from urllib.parse import urlencode
 
 from cytra import Application, json as jsonlib
 from cytra.db import DatabaseManager, metadata
-from cytra.helpers import NestedNamespace
+from cytra.helpers import dot_object
 
 
 class WebtestResponse(webtest.TestResponse):
     @property
     def json(self):
-        return NestedNamespace(super().json)
+        return dot_object(super().json)
 
 
 class WebtestRequest(webtest.TestRequest):
